@@ -253,8 +253,8 @@ def get_http_handler(
             raw_response = await run_in_threadpool(endpoint, **kwargs)
 
         if isinstance(raw_response, Response):
-            await send(raw_response.send_start)
-            await send(raw_response.send_body)
+            raw_response.request = request
+            await raw_response(scope, receive, send)
             return
 
         response_args: Dict[str, Any] = {}
@@ -277,8 +277,9 @@ def get_http_handler(
         if status_code is not None:
             response_args["status_code"] = status_code
         response = actual_response_class(result, **response_args)
-        await send(response.send_start)
-        await send(response.send_body)
+        # Temporary solution in order to avoid header initialization
+        response.request = request
+        await response(scope, receive, send)
 
     return app
 
